



pushd test-cmake
IF %ERRORLEVEL% NEQ 0 exit /B 1
cmake . -GNinja -DCMAKE_BUILD_TYPE=Release
IF %ERRORLEVEL% NEQ 0 exit /B 1
cmake --build . --verbose
IF %ERRORLEVEL% NEQ 0 exit /B 1
popd
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_aruco460.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_bgsegm460.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_calib3d460.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_ccalib460.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_core460.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_datasets460.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_features2d460.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_flann460.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_fuzzy460.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_highgui460.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_imgcodecs460.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_imgproc460.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_line_descriptor460.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_ml460.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_optflow460.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_phase_unwrapping460.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_photo460.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_plot460.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_reg460.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_rgbd460.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_saliency460.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_shape460.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_stereo460.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_stitching460.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_structured_light460.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_superres460.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_surface_matching460.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_tracking460.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_video460.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_videoio460.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_videostab460.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_xfeatures2d460.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_ximgproc460.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %CONDA_PREFIX%\\Library\\bin\\opencv_xphoto460.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
